.. currentmodule:: clouddrift

API
===

Auto-generated summary of CloudDrift's API. For more details and examples, refer to the different Jupyter Notebooks.

Adapters
--------

.. automodule:: clouddrift.adapters
  :members:
  :undoc-members:

GDP
^^^

.. automodule:: clouddrift.adapters.gdp
  :members:
  :undoc-members:

Analysis
--------

.. automodule:: clouddrift.analysis
  :members:
  :undoc-members:

Dataformat
----------

.. automodule:: clouddrift.dataformat
  :members:
  :undoc-members:

Haversine
---------

.. automodule:: clouddrift.haversine
  :members:
  :undoc-members:

Select
---------

.. automodule:: clouddrift.select
  :members:
  :undoc-members:

Sphere
---------

.. automodule:: clouddrift.sphere
  :members:
  :undoc-members:
